<a id="types-aiobotocore-config"></a>

# types-aiobotocore-config

[![PyPI - types-aiobotocore-config](https://img.shields.io/pypi/v/types-aiobotocore-config.svg?color=blue)](https://pypi.org/project/types-aiobotocore-config)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-config.svg?color=blue)](https://pypi.org/project/types-aiobotocore-config)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-config?color=blue)](https://pypistats.org/packages/types-aiobotocore-config)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.ConfigService 2.4.1](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/config.html#ConfigService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.11.11](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-config docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_config/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-config](#types-aiobotocore-config)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ConfigService` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[config]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[config]'


# standalone installation
python -m pip install types-aiobotocore-config
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-config
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[config]` in your environment:

```bash
python -m pip install 'types-aiobotocore[config]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[config]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[config]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[config]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[config]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[config]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[config]` in your environment:

```bash
python -m pip install 'types-aiobotocore[config]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[config]` in your environment:

```bash
python -m pip install 'types-aiobotocore[config]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ConfigServiceClient` provides annotations for
`session.create_client("config")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_config import ConfigServiceClient

session = get_session()
async with session.create_client("config") as client:
    client: ConfigServiceClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_config.paginator` module contains type annotations for all
paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_config import ConfigServiceClient
from types_aiobotocore_config.paginator import (
    DescribeAggregateComplianceByConfigRulesPaginator,
    DescribeAggregateComplianceByConformancePacksPaginator,
    DescribeAggregationAuthorizationsPaginator,
    DescribeComplianceByConfigRulePaginator,
    DescribeComplianceByResourcePaginator,
    DescribeConfigRuleEvaluationStatusPaginator,
    DescribeConfigRulesPaginator,
    DescribeConfigurationAggregatorSourcesStatusPaginator,
    DescribeConfigurationAggregatorsPaginator,
    DescribeConformancePackStatusPaginator,
    DescribeConformancePacksPaginator,
    DescribeOrganizationConfigRuleStatusesPaginator,
    DescribeOrganizationConfigRulesPaginator,
    DescribeOrganizationConformancePackStatusesPaginator,
    DescribeOrganizationConformancePacksPaginator,
    DescribePendingAggregationRequestsPaginator,
    DescribeRemediationExecutionStatusPaginator,
    DescribeRetentionConfigurationsPaginator,
    GetAggregateComplianceDetailsByConfigRulePaginator,
    GetComplianceDetailsByConfigRulePaginator,
    GetComplianceDetailsByResourcePaginator,
    GetConformancePackComplianceSummaryPaginator,
    GetOrganizationConfigRuleDetailedStatusPaginator,
    GetOrganizationConformancePackDetailedStatusPaginator,
    GetResourceConfigHistoryPaginator,
    ListAggregateDiscoveredResourcesPaginator,
    ListDiscoveredResourcesPaginator,
    ListTagsForResourcePaginator,
    SelectAggregateResourceConfigPaginator,
    SelectResourceConfigPaginator,
)

session = get_session()
async with session.create_client("config") as client:
    client: ConfigServiceClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    describe_aggregate_compliance_by_config_rules_paginator: DescribeAggregateComplianceByConfigRulesPaginator = client.get_paginator(
        "describe_aggregate_compliance_by_config_rules"
    )
    describe_aggregate_compliance_by_conformance_packs_paginator: DescribeAggregateComplianceByConformancePacksPaginator = client.get_paginator(
        "describe_aggregate_compliance_by_conformance_packs"
    )
    describe_aggregation_authorizations_paginator: DescribeAggregationAuthorizationsPaginator = (
        client.get_paginator("describe_aggregation_authorizations")
    )
    describe_compliance_by_config_rule_paginator: DescribeComplianceByConfigRulePaginator = (
        client.get_paginator("describe_compliance_by_config_rule")
    )
    describe_compliance_by_resource_paginator: DescribeComplianceByResourcePaginator = (
        client.get_paginator("describe_compliance_by_resource")
    )
    describe_config_rule_evaluation_status_paginator: DescribeConfigRuleEvaluationStatusPaginator = client.get_paginator(
        "describe_config_rule_evaluation_status"
    )
    describe_config_rules_paginator: DescribeConfigRulesPaginator = client.get_paginator(
        "describe_config_rules"
    )
    describe_configuration_aggregator_sources_status_paginator: DescribeConfigurationAggregatorSourcesStatusPaginator = client.get_paginator(
        "describe_configuration_aggregator_sources_status"
    )
    describe_configuration_aggregators_paginator: DescribeConfigurationAggregatorsPaginator = (
        client.get_paginator("describe_configuration_aggregators")
    )
    describe_conformance_pack_status_paginator: DescribeConformancePackStatusPaginator = (
        client.get_paginator("describe_conformance_pack_status")
    )
    describe_conformance_packs_paginator: DescribeConformancePacksPaginator = client.get_paginator(
        "describe_conformance_packs"
    )
    describe_organization_config_rule_statuses_paginator: DescribeOrganizationConfigRuleStatusesPaginator = client.get_paginator(
        "describe_organization_config_rule_statuses"
    )
    describe_organization_config_rules_paginator: DescribeOrganizationConfigRulesPaginator = (
        client.get_paginator("describe_organization_config_rules")
    )
    describe_organization_conformance_pack_statuses_paginator: DescribeOrganizationConformancePackStatusesPaginator = client.get_paginator(
        "describe_organization_conformance_pack_statuses"
    )
    describe_organization_conformance_packs_paginator: DescribeOrganizationConformancePacksPaginator = client.get_paginator(
        "describe_organization_conformance_packs"
    )
    describe_pending_aggregation_requests_paginator: DescribePendingAggregationRequestsPaginator = (
        client.get_paginator("describe_pending_aggregation_requests")
    )
    describe_remediation_execution_status_paginator: DescribeRemediationExecutionStatusPaginator = (
        client.get_paginator("describe_remediation_execution_status")
    )
    describe_retention_configurations_paginator: DescribeRetentionConfigurationsPaginator = (
        client.get_paginator("describe_retention_configurations")
    )
    get_aggregate_compliance_details_by_config_rule_paginator: GetAggregateComplianceDetailsByConfigRulePaginator = client.get_paginator(
        "get_aggregate_compliance_details_by_config_rule"
    )
    get_compliance_details_by_config_rule_paginator: GetComplianceDetailsByConfigRulePaginator = (
        client.get_paginator("get_compliance_details_by_config_rule")
    )
    get_compliance_details_by_resource_paginator: GetComplianceDetailsByResourcePaginator = (
        client.get_paginator("get_compliance_details_by_resource")
    )
    get_conformance_pack_compliance_summary_paginator: GetConformancePackComplianceSummaryPaginator = client.get_paginator(
        "get_conformance_pack_compliance_summary"
    )
    get_organization_config_rule_detailed_status_paginator: GetOrganizationConfigRuleDetailedStatusPaginator = client.get_paginator(
        "get_organization_config_rule_detailed_status"
    )
    get_organization_conformance_pack_detailed_status_paginator: GetOrganizationConformancePackDetailedStatusPaginator = client.get_paginator(
        "get_organization_conformance_pack_detailed_status"
    )
    get_resource_config_history_paginator: GetResourceConfigHistoryPaginator = client.get_paginator(
        "get_resource_config_history"
    )
    list_aggregate_discovered_resources_paginator: ListAggregateDiscoveredResourcesPaginator = (
        client.get_paginator("list_aggregate_discovered_resources")
    )
    list_discovered_resources_paginator: ListDiscoveredResourcesPaginator = client.get_paginator(
        "list_discovered_resources"
    )
    list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator(
        "list_tags_for_resource"
    )
    select_aggregate_resource_config_paginator: SelectAggregateResourceConfigPaginator = (
        client.get_paginator("select_aggregate_resource_config")
    )
    select_resource_config_paginator: SelectResourceConfigPaginator = client.get_paginator(
        "select_resource_config"
    )
```

<a id="literals"></a>

### Literals

`types_aiobotocore_config.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from types_aiobotocore_config.literals import (
    AggregateConformancePackComplianceSummaryGroupKeyType,
    AggregatedSourceStatusTypeType,
    AggregatedSourceTypeType,
    ChronologicalOrderType,
    ComplianceTypeType,
    ConfigRuleComplianceSummaryGroupKeyType,
    ConfigRuleStateType,
    ConfigurationItemStatusType,
    ConformancePackComplianceTypeType,
    ConformancePackStateType,
    DeliveryStatusType,
    DescribeAggregateComplianceByConfigRulesPaginatorName,
    DescribeAggregateComplianceByConformancePacksPaginatorName,
    DescribeAggregationAuthorizationsPaginatorName,
    DescribeComplianceByConfigRulePaginatorName,
    DescribeComplianceByResourcePaginatorName,
    DescribeConfigRuleEvaluationStatusPaginatorName,
    DescribeConfigRulesPaginatorName,
    DescribeConfigurationAggregatorSourcesStatusPaginatorName,
    DescribeConfigurationAggregatorsPaginatorName,
    DescribeConformancePackStatusPaginatorName,
    DescribeConformancePacksPaginatorName,
    DescribeOrganizationConfigRuleStatusesPaginatorName,
    DescribeOrganizationConfigRulesPaginatorName,
    DescribeOrganizationConformancePackStatusesPaginatorName,
    DescribeOrganizationConformancePacksPaginatorName,
    DescribePendingAggregationRequestsPaginatorName,
    DescribeRemediationExecutionStatusPaginatorName,
    DescribeRetentionConfigurationsPaginatorName,
    EventSourceType,
    GetAggregateComplianceDetailsByConfigRulePaginatorName,
    GetComplianceDetailsByConfigRulePaginatorName,
    GetComplianceDetailsByResourcePaginatorName,
    GetConformancePackComplianceSummaryPaginatorName,
    GetOrganizationConfigRuleDetailedStatusPaginatorName,
    GetOrganizationConformancePackDetailedStatusPaginatorName,
    GetResourceConfigHistoryPaginatorName,
    ListAggregateDiscoveredResourcesPaginatorName,
    ListDiscoveredResourcesPaginatorName,
    ListTagsForResourcePaginatorName,
    MaximumExecutionFrequencyType,
    MemberAccountRuleStatusType,
    MessageTypeType,
    OrganizationConfigRuleTriggerTypeNoSNType,
    OrganizationConfigRuleTriggerTypeType,
    OrganizationResourceDetailedStatusType,
    OrganizationResourceStatusType,
    OrganizationRuleStatusType,
    OwnerType,
    RecorderStatusType,
    RemediationExecutionStateType,
    RemediationExecutionStepStateType,
    RemediationTargetTypeType,
    ResourceCountGroupKeyType,
    ResourceTypeType,
    ResourceValueTypeType,
    SelectAggregateResourceConfigPaginatorName,
    SelectResourceConfigPaginatorName,
    SortByType,
    SortOrderType,
    ConfigServiceServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AggregateConformancePackComplianceSummaryGroupKeyType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_config.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_config.type_defs import (
    AccountAggregationSourceTypeDef,
    AggregateConformancePackComplianceTypeDef,
    AggregateConformancePackComplianceCountTypeDef,
    AggregateConformancePackComplianceFiltersTypeDef,
    AggregateConformancePackComplianceSummaryFiltersTypeDef,
    AggregateResourceIdentifierTypeDef,
    AggregatedSourceStatusTypeDef,
    AggregationAuthorizationTypeDef,
    BaseConfigurationItemTypeDef,
    ResponseMetadataTypeDef,
    ResourceKeyTypeDef,
    ComplianceContributorCountTypeDef,
    ConfigExportDeliveryInfoTypeDef,
    ConfigRuleComplianceFiltersTypeDef,
    ConfigRuleComplianceSummaryFiltersTypeDef,
    ConfigRuleEvaluationStatusTypeDef,
    ScopeTypeDef,
    ConfigSnapshotDeliveryPropertiesTypeDef,
    ConfigStreamDeliveryInfoTypeDef,
    OrganizationAggregationSourceTypeDef,
    RelationshipTypeDef,
    ConfigurationRecorderStatusTypeDef,
    RecordingGroupTypeDef,
    ConformancePackComplianceFiltersTypeDef,
    ConformancePackComplianceScoreTypeDef,
    ConformancePackComplianceScoresFiltersTypeDef,
    ConformancePackComplianceSummaryTypeDef,
    ConformancePackInputParameterTypeDef,
    TemplateSSMDocumentDetailsTypeDef,
    ConformancePackEvaluationFiltersTypeDef,
    ConformancePackRuleComplianceTypeDef,
    ConformancePackStatusDetailTypeDef,
    CustomPolicyDetailsTypeDef,
    DeleteAggregationAuthorizationRequestRequestTypeDef,
    DeleteConfigRuleRequestRequestTypeDef,
    DeleteConfigurationAggregatorRequestRequestTypeDef,
    DeleteConfigurationRecorderRequestRequestTypeDef,
    DeleteConformancePackRequestRequestTypeDef,
    DeleteDeliveryChannelRequestRequestTypeDef,
    DeleteEvaluationResultsRequestRequestTypeDef,
    DeleteOrganizationConfigRuleRequestRequestTypeDef,
    DeleteOrganizationConformancePackRequestRequestTypeDef,
    DeletePendingAggregationRequestRequestRequestTypeDef,
    DeleteRemediationConfigurationRequestRequestTypeDef,
    RemediationExceptionResourceKeyTypeDef,
    DeleteResourceConfigRequestRequestTypeDef,
    DeleteRetentionConfigurationRequestRequestTypeDef,
    DeleteStoredQueryRequestRequestTypeDef,
    DeliverConfigSnapshotRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    DescribeAggregationAuthorizationsRequestRequestTypeDef,
    DescribeComplianceByConfigRuleRequestRequestTypeDef,
    DescribeComplianceByResourceRequestRequestTypeDef,
    DescribeConfigRuleEvaluationStatusRequestRequestTypeDef,
    DescribeConfigRulesRequestRequestTypeDef,
    DescribeConfigurationAggregatorSourcesStatusRequestRequestTypeDef,
    DescribeConfigurationAggregatorsRequestRequestTypeDef,
    DescribeConfigurationRecorderStatusRequestRequestTypeDef,
    DescribeConfigurationRecordersRequestRequestTypeDef,
    DescribeConformancePackStatusRequestRequestTypeDef,
    DescribeConformancePacksRequestRequestTypeDef,
    DescribeDeliveryChannelStatusRequestRequestTypeDef,
    DescribeDeliveryChannelsRequestRequestTypeDef,
    DescribeOrganizationConfigRuleStatusesRequestRequestTypeDef,
    OrganizationConfigRuleStatusTypeDef,
    DescribeOrganizationConfigRulesRequestRequestTypeDef,
    DescribeOrganizationConformancePackStatusesRequestRequestTypeDef,
    OrganizationConformancePackStatusTypeDef,
    DescribeOrganizationConformancePacksRequestRequestTypeDef,
    DescribePendingAggregationRequestsRequestRequestTypeDef,
    PendingAggregationRequestTypeDef,
    DescribeRemediationConfigurationsRequestRequestTypeDef,
    RemediationExceptionTypeDef,
    DescribeRetentionConfigurationsRequestRequestTypeDef,
    RetentionConfigurationTypeDef,
    EvaluationResultQualifierTypeDef,
    EvaluationTypeDef,
    SsmControlsTypeDef,
    ExternalEvaluationTypeDef,
    FieldInfoTypeDef,
    GetAggregateComplianceDetailsByConfigRuleRequestRequestTypeDef,
    ResourceCountFiltersTypeDef,
    GroupedResourceCountTypeDef,
    GetComplianceDetailsByConfigRuleRequestRequestTypeDef,
    GetComplianceDetailsByResourceRequestRequestTypeDef,
    GetComplianceSummaryByResourceTypeRequestRequestTypeDef,
    GetConformancePackComplianceSummaryRequestRequestTypeDef,
    GetCustomRulePolicyRequestRequestTypeDef,
    GetDiscoveredResourceCountsRequestRequestTypeDef,
    ResourceCountTypeDef,
    StatusDetailFiltersTypeDef,
    MemberAccountStatusTypeDef,
    OrganizationResourceDetailedStatusFiltersTypeDef,
    OrganizationConformancePackDetailedStatusTypeDef,
    GetOrganizationCustomRulePolicyRequestRequestTypeDef,
    GetResourceConfigHistoryRequestRequestTypeDef,
    GetStoredQueryRequestRequestTypeDef,
    StoredQueryTypeDef,
    ResourceFiltersTypeDef,
    ListDiscoveredResourcesRequestRequestTypeDef,
    ResourceIdentifierTypeDef,
    ListStoredQueriesRequestRequestTypeDef,
    StoredQueryMetadataTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    TagTypeDef,
    OrganizationCustomPolicyRuleMetadataNoPolicyTypeDef,
    OrganizationCustomRuleMetadataTypeDef,
    OrganizationManagedRuleMetadataTypeDef,
    OrganizationCustomPolicyRuleMetadataTypeDef,
    PutResourceConfigRequestRequestTypeDef,
    PutRetentionConfigurationRequestRequestTypeDef,
    RemediationExecutionStepTypeDef,
    ResourceValueTypeDef,
    StaticValueTypeDef,
    SelectAggregateResourceConfigRequestRequestTypeDef,
    SelectResourceConfigRequestRequestTypeDef,
    SourceDetailTypeDef,
    StartConfigRulesEvaluationRequestRequestTypeDef,
    StartConfigurationRecorderRequestRequestTypeDef,
    StopConfigurationRecorderRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    AggregateComplianceByConformancePackTypeDef,
    AggregateConformancePackComplianceSummaryTypeDef,
    DescribeAggregateComplianceByConformancePacksRequestRequestTypeDef,
    GetAggregateConformancePackComplianceSummaryRequestRequestTypeDef,
    BatchGetAggregateResourceConfigRequestRequestTypeDef,
    GetAggregateResourceConfigRequestRequestTypeDef,
    BatchGetAggregateResourceConfigResponseTypeDef,
    DeliverConfigSnapshotResponseTypeDef,
    DescribeAggregationAuthorizationsResponseTypeDef,
    DescribeConfigurationAggregatorSourcesStatusResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    GetCustomRulePolicyResponseTypeDef,
    GetOrganizationCustomRulePolicyResponseTypeDef,
    ListAggregateDiscoveredResourcesResponseTypeDef,
    PutAggregationAuthorizationResponseTypeDef,
    PutConformancePackResponseTypeDef,
    PutOrganizationConfigRuleResponseTypeDef,
    PutOrganizationConformancePackResponseTypeDef,
    PutStoredQueryResponseTypeDef,
    BatchGetResourceConfigRequestRequestTypeDef,
    BatchGetResourceConfigResponseTypeDef,
    DescribeRemediationExecutionStatusRequestRequestTypeDef,
    StartRemediationExecutionRequestRequestTypeDef,
    StartRemediationExecutionResponseTypeDef,
    ComplianceSummaryTypeDef,
    ComplianceTypeDef,
    DescribeAggregateComplianceByConfigRulesRequestRequestTypeDef,
    GetAggregateConfigRuleComplianceSummaryRequestRequestTypeDef,
    DescribeConfigRuleEvaluationStatusResponseTypeDef,
    DeliveryChannelTypeDef,
    DeliveryChannelStatusTypeDef,
    ConfigurationAggregatorTypeDef,
    ConfigurationItemTypeDef,
    DescribeConfigurationRecorderStatusResponseTypeDef,
    ConfigurationRecorderTypeDef,
    DescribeConformancePackComplianceRequestRequestTypeDef,
    ListConformancePackComplianceScoresResponseTypeDef,
    ListConformancePackComplianceScoresRequestRequestTypeDef,
    GetConformancePackComplianceSummaryResponseTypeDef,
    OrganizationConformancePackTypeDef,
    PutOrganizationConformancePackRequestRequestTypeDef,
    ConformancePackDetailTypeDef,
    PutConformancePackRequestRequestTypeDef,
    GetConformancePackComplianceDetailsRequestRequestTypeDef,
    DescribeConformancePackComplianceResponseTypeDef,
    DescribeConformancePackStatusResponseTypeDef,
    DeleteRemediationExceptionsRequestRequestTypeDef,
    DescribeRemediationExceptionsRequestRequestTypeDef,
    FailedDeleteRemediationExceptionsBatchTypeDef,
    PutRemediationExceptionsRequestRequestTypeDef,
    DescribeAggregateComplianceByConfigRulesRequestDescribeAggregateComplianceByConfigRulesPaginateTypeDef,
    DescribeAggregateComplianceByConformancePacksRequestDescribeAggregateComplianceByConformancePacksPaginateTypeDef,
    DescribeAggregationAuthorizationsRequestDescribeAggregationAuthorizationsPaginateTypeDef,
    DescribeComplianceByConfigRuleRequestDescribeComplianceByConfigRulePaginateTypeDef,
    DescribeComplianceByResourceRequestDescribeComplianceByResourcePaginateTypeDef,
    DescribeConfigRuleEvaluationStatusRequestDescribeConfigRuleEvaluationStatusPaginateTypeDef,
    DescribeConfigRulesRequestDescribeConfigRulesPaginateTypeDef,
    DescribeConfigurationAggregatorSourcesStatusRequestDescribeConfigurationAggregatorSourcesStatusPaginateTypeDef,
    DescribeConfigurationAggregatorsRequestDescribeConfigurationAggregatorsPaginateTypeDef,
    DescribeConformancePackStatusRequestDescribeConformancePackStatusPaginateTypeDef,
    DescribeConformancePacksRequestDescribeConformancePacksPaginateTypeDef,
    DescribeOrganizationConfigRuleStatusesRequestDescribeOrganizationConfigRuleStatusesPaginateTypeDef,
    DescribeOrganizationConfigRulesRequestDescribeOrganizationConfigRulesPaginateTypeDef,
    DescribeOrganizationConformancePackStatusesRequestDescribeOrganizationConformancePackStatusesPaginateTypeDef,
    DescribeOrganizationConformancePacksRequestDescribeOrganizationConformancePacksPaginateTypeDef,
    DescribePendingAggregationRequestsRequestDescribePendingAggregationRequestsPaginateTypeDef,
    DescribeRemediationExecutionStatusRequestDescribeRemediationExecutionStatusPaginateTypeDef,
    DescribeRetentionConfigurationsRequestDescribeRetentionConfigurationsPaginateTypeDef,
    GetAggregateComplianceDetailsByConfigRuleRequestGetAggregateComplianceDetailsByConfigRulePaginateTypeDef,
    GetComplianceDetailsByConfigRuleRequestGetComplianceDetailsByConfigRulePaginateTypeDef,
    GetComplianceDetailsByResourceRequestGetComplianceDetailsByResourcePaginateTypeDef,
    GetConformancePackComplianceSummaryRequestGetConformancePackComplianceSummaryPaginateTypeDef,
    GetResourceConfigHistoryRequestGetResourceConfigHistoryPaginateTypeDef,
    ListDiscoveredResourcesRequestListDiscoveredResourcesPaginateTypeDef,
    ListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
    SelectAggregateResourceConfigRequestSelectAggregateResourceConfigPaginateTypeDef,
    SelectResourceConfigRequestSelectResourceConfigPaginateTypeDef,
    DescribeOrganizationConfigRuleStatusesResponseTypeDef,
    DescribeOrganizationConformancePackStatusesResponseTypeDef,
    DescribePendingAggregationRequestsResponseTypeDef,
    DescribeRemediationExceptionsResponseTypeDef,
    FailedRemediationExceptionBatchTypeDef,
    DescribeRetentionConfigurationsResponseTypeDef,
    PutRetentionConfigurationResponseTypeDef,
    EvaluationResultIdentifierTypeDef,
    PutEvaluationsRequestRequestTypeDef,
    PutEvaluationsResponseTypeDef,
    ExecutionControlsTypeDef,
    PutExternalEvaluationRequestRequestTypeDef,
    QueryInfoTypeDef,
    GetAggregateDiscoveredResourceCountsRequestRequestTypeDef,
    GetAggregateDiscoveredResourceCountsResponseTypeDef,
    GetDiscoveredResourceCountsResponseTypeDef,
    GetOrganizationConfigRuleDetailedStatusRequestGetOrganizationConfigRuleDetailedStatusPaginateTypeDef,
    GetOrganizationConfigRuleDetailedStatusRequestRequestTypeDef,
    GetOrganizationConfigRuleDetailedStatusResponseTypeDef,
    GetOrganizationConformancePackDetailedStatusRequestGetOrganizationConformancePackDetailedStatusPaginateTypeDef,
    GetOrganizationConformancePackDetailedStatusRequestRequestTypeDef,
    GetOrganizationConformancePackDetailedStatusResponseTypeDef,
    GetStoredQueryResponseTypeDef,
    ListAggregateDiscoveredResourcesRequestListAggregateDiscoveredResourcesPaginateTypeDef,
    ListAggregateDiscoveredResourcesRequestRequestTypeDef,
    ListDiscoveredResourcesResponseTypeDef,
    ListStoredQueriesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PutAggregationAuthorizationRequestRequestTypeDef,
    PutConfigurationAggregatorRequestRequestTypeDef,
    PutStoredQueryRequestRequestTypeDef,
    TagResourceRequestRequestTypeDef,
    OrganizationConfigRuleTypeDef,
    PutOrganizationConfigRuleRequestRequestTypeDef,
    RemediationExecutionStatusTypeDef,
    RemediationParameterValueTypeDef,
    SourceTypeDef,
    DescribeAggregateComplianceByConformancePacksResponseTypeDef,
    GetAggregateConformancePackComplianceSummaryResponseTypeDef,
    AggregateComplianceCountTypeDef,
    ComplianceSummaryByResourceTypeTypeDef,
    GetComplianceSummaryByConfigRuleResponseTypeDef,
    AggregateComplianceByConfigRuleTypeDef,
    ComplianceByConfigRuleTypeDef,
    ComplianceByResourceTypeDef,
    DescribeDeliveryChannelsResponseTypeDef,
    PutDeliveryChannelRequestRequestTypeDef,
    DescribeDeliveryChannelStatusResponseTypeDef,
    DescribeConfigurationAggregatorsResponseTypeDef,
    PutConfigurationAggregatorResponseTypeDef,
    GetAggregateResourceConfigResponseTypeDef,
    GetResourceConfigHistoryResponseTypeDef,
    DescribeConfigurationRecordersResponseTypeDef,
    PutConfigurationRecorderRequestRequestTypeDef,
    DescribeOrganizationConformancePacksResponseTypeDef,
    DescribeConformancePacksResponseTypeDef,
    DeleteRemediationExceptionsResponseTypeDef,
    PutRemediationExceptionsResponseTypeDef,
    AggregateEvaluationResultTypeDef,
    ConformancePackEvaluationResultTypeDef,
    EvaluationResultTypeDef,
    SelectAggregateResourceConfigResponseTypeDef,
    SelectResourceConfigResponseTypeDef,
    DescribeOrganizationConfigRulesResponseTypeDef,
    DescribeRemediationExecutionStatusResponseTypeDef,
    RemediationConfigurationTypeDef,
    ConfigRuleTypeDef,
    GetAggregateConfigRuleComplianceSummaryResponseTypeDef,
    GetComplianceSummaryByResourceTypeResponseTypeDef,
    DescribeAggregateComplianceByConfigRulesResponseTypeDef,
    DescribeComplianceByConfigRuleResponseTypeDef,
    DescribeComplianceByResourceResponseTypeDef,
    GetAggregateComplianceDetailsByConfigRuleResponseTypeDef,
    GetConformancePackComplianceDetailsResponseTypeDef,
    GetComplianceDetailsByConfigRuleResponseTypeDef,
    GetComplianceDetailsByResourceResponseTypeDef,
    DescribeRemediationConfigurationsResponseTypeDef,
    FailedRemediationBatchTypeDef,
    PutRemediationConfigurationsRequestRequestTypeDef,
    DescribeConfigRulesResponseTypeDef,
    PutConfigRuleRequestRequestTypeDef,
    PutRemediationConfigurationsResponseTypeDef,
)


def get_structure() -> AccountAggregationSourceTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-config` version is the same as related `aiobotocore` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_config/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
